Normal attr - 常规属性
======================

常规属性的含义请看\ :ref:`这里 <intro_normal_attr>`。

下面这个装饰器就是各知乎类中用于标明哪些是常规属性的，
类里的定义只是为了方便构建文档。真正返回常规数据的操作均由这一装饰器完成。

..  automodule:: zhihu_oauth.zhcls.normal
    :members:
    :special-members:
    :undoc-members:
